summaryrefslogtreecommitdiff
path: root/chart2/source/inc/DiagramHelper.hxx
diff options
context:
space:
mode:
Diffstat (limited to 'chart2/source/inc/DiagramHelper.hxx')
-rw-r--r--chart2/source/inc/DiagramHelper.hxx6
1 files changed, 3 insertions, 3 deletions
diff --git a/chart2/source/inc/DiagramHelper.hxx b/chart2/source/inc/DiagramHelper.hxx
index c7cda6189680..b01255a81698 100644
--- a/chart2/source/inc/DiagramHelper.hxx
+++ b/chart2/source/inc/DiagramHelper.hxx
@@ -108,7 +108,7 @@ public:
);
/** @param bOnlyAtFirstChartType
- If </TRUE>, the stacking mode is only set at the series found inside
+ If </sal_True>, the stacking mode is only set at the series found inside
the first chart type. This is the standard for all current
templates (the only template that has more than one chart-type and
allows stacking is bar/line combi, and for this the stacking only
@@ -270,7 +270,7 @@ public:
* @param bForward
* Direction of the move to be checked.
*
* @returns </TRUE> if the series can be moved.
*
*/
static bool isSeriesMoveable(
@@ -292,7 +292,7 @@ public:
* @param bForward
* Direction in which the series should be moved.
*
* @returns </TRUE> if the series was moved successfully.
*
*/
static bool moveSeries(
@@ -270,7 +270,7 @@ public:
* Direction of the move to be checked.
*
- * @returns </TRUE> if the series can be moved.
+ * @returns </sal_True> if the series can be moved.
*
*/
@@ -292,7 +292,7 @@ public:
* Direction in which the series should be moved.
*
- * @returns </TRUE> if the series was moved successfully.
+ * @returns </sal_True> if the series was moved successfully.
*
*/